pitchtools.diatonic_pitch_class_number_to_diatonic_pitch_class_name
===================================================================

.. autofunction:: abjad.tools.pitchtools.diatonic_pitch_class_number_to_diatonic_pitch_class_name.diatonic_pitch_class_number_to_diatonic_pitch_class_name
